@@ -1,7 +1,7 @@
 import functools
 import hashlib
 
-from lib.util import parse_config
+from dorothy.lib.util import parse_config
 
 def require_params(*args, **kwargs):
     required_params = args
