@@ -1,4 +1,4 @@
-from lib import xjson
+from dorothy.lib import xjson
 
 
 class ApiError(Exception):
